#!/bin/sh
# Bash uses BCM GPIO numbers (i.e. the pin names of the Broadcom Chip itself)
# These are detailed in the Raspberry Pi wiki pages.

#Setup Pins---assign pin numbers to names
LED_G=4
LED_R=27    #Rev2.0 (Ensure you use correct one for your board)
LED_Y=17

#Setup Active states
#Common Cathode RGY-LEDs (Cathode=Active Low)
LED_ENABLE=0    #active low
LED_DISABLE=1

#Set GPIO pins to output and put in disable state

#export pin number: ask kernel to export pin control to userspace
echo "$LED_R" > /sys/class/gpio/export
# equivalent to: echo "27" > /sys/class/gpio/export
echo "$LED_G" > /sys/class/gpio/export
echo "$LED_Y" > /sys/class/gpio/export

#set the pins to output
echo "out" > /sys/class/gpio/gpio$LED_R/direction
# equivalent to: echo "out" > /sys/class/gpio/gpio27/direction
echo "out" > /sys/class/gpio/gpio$LED_G/direction
echo "out" > /sys/class/gpio/gpio$LED_Y/direction

#set the voltage output on the pin
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_R/value
# equivalent to: echo "1" > /sys/class/gpio/gpio27/value
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_G/value
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_Y/value
# Setup End
############################################################

#Switch on RED/GREEN/YELLOW LEDs
echo "$LED_ENABLE" > /sys/class/gpio/gpio$LED_R/value
# equivalent to: echo "0" > /sys/class/gpio/gpio27/value
echo "$LED_ENABLE" > /sys/class/gpio/gpio$LED_G/value
echo "$LED_ENABLE" > /sys/class/gpio/gpio$LED_Y/value

#Wait
sleep 1s

#Switch each LED off
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_R/value
# equivalent to: echo "1" > /sys/class/gpio/gpio27/value
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_G/value
echo "$LED_DISABLE" > /sys/class/gpio/gpio$LED_Y/value

############################################################
# Clean Up
echo "$LED_R" > /sys/class/gpio/unexport
# equivalent to: echo "27" > /sys/class/gpio/unexport
echo "$LED_G" > /sys/class/gpio/unexport
echo "$LED_Y" > /sys/class/gpio/unexport
#End
